@@ -94,7 +94,6 @@ def include_includes(parameters, model_fp):
 @click.option("-y", "skip_confirm", is_flag=True, help="Skip confirmation prompt")
 def model_update(
     channel=None,
-    work_dir=None,
     nomitall_secret=None,
     nomitall=None,
     dry_run=None,
@@ -116,7 +115,7 @@ def model_update(
         org = profile.get(config["COGNITO_USERPOOL_ID"], {}).get("default-org")
         if not org:
             raise ClickException(
-                f"No profile found for nomitall {nomitall_url}, try re-logging"
+                f"No profile found for nomitall {nomitall_url}, try re-logging with `nnd login --nomitall-url {nomitall_url}`"
             )
     if channel == "beta":
         c_color = click.style(channel, fg="yellow", bold=True)
@@ -125,13 +124,17 @@ def model_update(
     else:
         c_color = click.style(channel, fg="green", bold=True)
 
+    doc = yaml.full_load(Path(model_fn).read_text())
     if not skip_confirm:
         click.confirm(
-            text=f"Confirm model update:\n\tModel: {model_fn}\n\tChannel: {c_color}\n\tNomitall: {nomitall}\n",
+            text=f"Confirm model update:"
+            f"\n\tUUID: {doc.get('uuid','Not Found')}"
+            f"\n\tModel File: {model_fn}"
+            f"\n\tChannel: {c_color}"
+            f"\n\tNomitall: {nomitall}\n",
             abort=True,
         )
 
-    doc = yaml.full_load(Path(model_fn).read_text())
     model_type = doc.get("type")
     if not model_type:
         _logger.error("Model does not have a type, this is required")
@@ -219,12 +222,10 @@ def update_model(nomitall_url, nomitall_secret, model, model_type, org, channel)
     elif model_type == "shared_config_type":
         _logger.info("Pushing shared config type to nomitall")
         resp = session.request("POST", "shared_config_type/update", json=model)
-        check_response(resp)
 
     elif model_type == "shared_field_type":
         _logger.info("Pushing shared field type to nomitall")
         resp = session.request("POST", "shared_field_type/update", json=model)
-        check_response(resp)
 
     elif model_type == "shared_object_type":
         _logger.info("Pushing shared object type to nomitall")
